@@ -14,7 +14,7 @@ extern char cj[][JSentLen], cz[][CzLen], md[][JSentLen], mz[][ZokuLen],
 extern char en[][JSentLen];
 char wd[WordLen];
 static char op = 0x28, cp = 0x29;
-char *plu = "addendum,addenda;alga,algae;alto,altos;alumna,alumnae;alumus,alumni;analysis,analyses;antelope,antelopes;antenna,antennas;apex,apexes;appendix,appendixes;aquarium,aquariums;archipelago,archipelagos;automation,automatons;axis,axes;bacillus,bacilli;bacterium,bacteria;banjo,banjoes;basis,bases;brther-in-law,brothers-in-law;buffalo,buffalos;bureau,bureaus;craftsman,craftsmen;man,men;shelf,shelves;woman,women;";
+char *plu = "addendum,addenda;alga,algae;alto,altos;alumna,alumnae;alumus,alumni;analysis,analyses;antelope,antelopes;antenna,antennas;apex,apexes;appendix,appendixes;aquarium,aquariums;archipelago,archipelagos;automation,automatons;axis,axes;bacillus,bacilli;bacterium,bacteria;banjo,banjoes;basis,bases;brther-in-law,brothers-in-law;buffalo,buffalos;bureau,bureaus;cactus,cacti;calf,calves;cargo,cargos;cello,cellos;chamois,chamois;chassis,chassis;child,children;codex,codices;command,commandos;concerto,concertos;corpus,corpora;crisis,crises;craftsman,craftsmen;criterion,criteria;man,men;shelf,shelves;woman,women;";
 
 static char bungo[14][18] = {"ł","ł( 2)","(ł 3)",
 	"Ȃ( 3)","͂Ȃ","Ȃ","͂Ȃ( 3)",
@@ -46,10 +46,12 @@ int  sw;
     int  k, j, ln;
     char *pt;
     if(strncmp(yk+1, "also ", 5) == 0) return;
+    if(strcmp(yk+1, "there be") == 0){ strcpy(yk+7, "was"); return; }
     if(strcmp(yk+1, "there is") == 0){ strcpy(yk+7, "was"); return; }
+    if(strcmp(yk+1, "there are") == 0){ strcpy(yk+7, "were"); return; }
     if(strncmp(yk+1, "is ", 3) == 0){ ptreplace(yk+1, 2, "was"); return; }
     if(strncmp(yk+1, "are ", 4) == 0){ ptreplace(yk+1, 3, "were"); return; }
-    if(strncmp(yk+1, "has ", 4) == 0){ ptreplace(yk+1, 3, "have"); }
+    if(strncmp(yk+1, "has ", 4) == 0 || strcmp(yk+1, "has") == 0){ ptreplace(yk+1, 3, "have"); }
     if(strncmp(yk+1, "play ", 5) == 0){ ptreplace(yk+1, 4, "played"); }
     if((pt = (char*)strchr(yk, ' '))) ;
     else pt = (char*)strchr(yk, '\0');
@@ -58,6 +60,7 @@ int  sw;
     if(irregVerb(sw) == 1){ ptreplace(yk+1, ln, wd); return; }
 //    if(strncmp(wd, yk+1, ln) != 0){ ptreplace(yk+1, ln, wd); return; }
     if(strcmp(wd, "could") == 0 || strcmp(wd, "should") == 0) return;
+    if(strcmp(wd, "has") == 0) return;
     if(*(pt-1) == 'e') ptinsert(pt, "d");    
     else if(*(pt-1) == 'y') ptreplace(pt-1, 1, "ied");    
     else if(*(pt-1) == 'p') ptinsert(pt, "ped");    
@@ -226,7 +229,7 @@ char *pt;
         return;
       }
     AT:
-      if(strstr(mz[i], "") ) return;
+      if(strstr(mz[i], "") || strchr(mz[i], 'n') ) return;
       if(strstr(mz[i], "") == 0 || strstr(mz[i], "P") || strchr(mz[i], 'y')){
         if(md[i+1][0] == '7') strcpy(buf, "the ");
         else if(strstr(mz[i], ""))  return;
@@ -408,6 +411,12 @@ char mdi[], mzi[], mdj[], mzj[];
     if(strncmp(mdi+1, "should ", 7) == 0) return;
     if(strncmp(mdi+1, "would ", 6) == 0) return;
     if(strncmp(mdi+1, "almost ", 7) == 0) return;
+    if(strncmp(mdi+1, "there be", 8) == 0 ){
+      if(strstr(mzj, "") ){
+	ptreplace(mdi+7, 2, "are");    return;
+      }
+	ptreplace(mdi+7, 2, "is");    return;
+    }
     if(strncmp(mdi+1, "be ", 3) == 0 || strcmp(mdi+1, "be") == 0){
       if(strncmp(mdj+1, "either", 6) == 0 && (pt =(char*)strrchr(mdj+1, ' '))){
         strcpy(mdjb, pt+1);
@@ -1144,6 +1153,7 @@ char kaz[30];
 {
     char bj[100];
     strcpy(bj, md[i]);
+    if(strncmp(bj+1, "Japanese", 8) == 0) return;
     strcat(bj, "s");
     strcpy(md[i],bj);
 }
@@ -1153,6 +1163,7 @@ char *wd;
 {
   int n;
   char buf[400], *pt, *pt1, *pt2;
+  if(strlen(wd) == 0) return(0);
   strcpy(buf, wd);
   if(pt1 = strchr(buf, ' ')) *pt1 = '\0';
   n = strlen(buf);
