@@ -68,7 +68,12 @@ char *argv[];
     arrow = 0;
     while(1){
       if(GetSentence() != 0) break;
+
+#ifdef __linux
+      sjis2utf8(jps); // UTF-8ŏo
+#else
       puts(jps);
+#endif
 
       if(html_f != 0 || script > 0 || jps[strlen(jps)-1] == '>'
       || strncmp(jps, "/*", 2) == 0 
@@ -449,6 +454,7 @@ siage()
     if(pt) ptreplace(pt, 7, "wasn't");
     if((pt = (char*)strstr(egs, "do not"))) ptreplace(pt, 6, "don't");
     if((pt = (char*)strstr(egs, "does not"))) ptreplace(pt, 8, "doesn't");
+    if((pt = (char*)strstr(egs, "can not"))) ptreplace(pt, 7, "can't");
     if(isalnum(egs[0])) egs[0] = toupper(egs[0]);
     if(Dbg == 'Y') fprintf(dbg, "--- siage --- egs = %s \n", egs);
 }
@@ -509,7 +515,7 @@ predit()
     if(pt = (char*)strstr(wdh, "ƍKł")) ptreplace(pt, 10, "ĉ");
     if(pt = (char*)strstr(wdh, "āB")) ptreplace(pt, 6, "ĉB");
     if(pt = (char*)strstr(wdh, "ȂA")) ptreplace(pt+6, 4, "A");
-    if(pt = (char*)strstr(wdh, "")) ptreplace(pt, 6, "");
+    if((pt = (char*)strstr(wdh, "")) && strncmp(pt+6, "", 4)) ptreplace(pt, 6, "");
     if((pt = (char*)strstr(wdh, "Ȃ̂")) && strncmp(pt-4, "", 4)) ptreplace(pt, 2, "ł");
     if(pt = (char*)strstr(wdh, "ɏ")) ptreplace(pt, 8, "̏");
     if(pt = (char*)strstr(wdh, "̂")) ptreplace(pt, 8, "̌`");
